aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKirk McKusick <mckusick@FreeBSD.org>2018-08-23 22:35:14 +0000
committerKirk McKusick <mckusick@FreeBSD.org>2018-08-23 22:35:14 +0000
commita9c2220f5c4150dab2782e524cdc1ecded141529 (patch)
tree881945bf098123af5afc350d345701a6ca8ade6d
parent602a05b0da13792f5ab0c1c4f9daa8e8b2deb70e (diff)
Notes
-rw-r--r--sys/ufs/ffs/ffs_alloc.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/ufs/ffs/ffs_alloc.c b/sys/ufs/ffs/ffs_alloc.c
index 6b69ffa078f06..6cbec2d151e6e 100644
--- a/sys/ufs/ffs/ffs_alloc.c
+++ b/sys/ufs/ffs/ffs_alloc.c
@@ -486,7 +486,7 @@ SYSCTL_INT(_vfs_ffs, OID_AUTO, doreallocblks, CTLFLAG_RW, &doreallocblks, 0,
static int dotrimcons = 0;
SYSCTL_INT(_vfs_ffs, OID_AUTO, dotrimcons, CTLFLAG_RW, &dotrimcons, 0,
-"enable BIO_DELETE / TRIM consolodation");
+"enable BIO_DELETE / TRIM consolidation");
static int maxclustersearch = 10;
SYSCTL_INT(_vfs_ffs, OID_AUTO, maxclustersearch, CTLFLAG_RW, &maxclustersearch,
@@ -513,10 +513,10 @@ ffs_reallocblks(ap)
* the destination for the data is usually moved before the data
* is written to the initially allocated location, so we rarely
* suffer the penalty of extra writes. With the addition of the
* consolodation of contiguous blocks into single BIO_DELETE
* operations, having fewer but larger contiguous blocks reduces
* the number of (slow and expensive) BIO_DELETE operations. So
* when doing BIO_DELETE consolodation, we do block reallocation.
*
* Skip if reallocblks has been disabled globally.
*/
@@ -513,10 +513,10 @@ ffs_reallocblks(ap)
* is written to the initially allocated location, so we rarely
* suffer the penalty of extra writes. With the addition of the
- * consolodation of contiguous blocks into single BIO_DELETE
+ * consolidation of contiguous blocks into single BIO_DELETE
* operations, having fewer but larger contiguous blocks reduces
* the number of (slow and expensive) BIO_DELETE operations. So
@@ -513,10 +513,10 @@ ffs_reallocblks(ap)
* operations, having fewer but larger contiguous blocks reduces
* the number of (slow and expensive) BIO_DELETE operations. So
- * when doing BIO_DELETE consolodation, we do block reallocation.
+ * when doing BIO_DELETE consolidation, we do block reallocation.
*
* Skip if reallocblks has been disabled globally.